@@ -75,6 +75,21 @@ static VALUE rb_git_libgit2_version(VALUE self)
 	return rb_ary_new3(3, INT2NUM(major), INT2NUM(minor), INT2NUM(rev));
 }
 
+/*
+ *  call-seq:
+ *     Rugged.libgit2_prerelease -> prerelease string
+ *
+ *  Returns a string with the prerelease string for libgit2. This will be empty
+ *  for tagged releases.
+ */
+static VALUE rb_git_libgit2_prerelease(VALUE self)
+{
+	const char *prerelease;
+
+	prerelease = git_libgit2_prerelease();
+	return rb_str_new_utf8(prerelease ? prerelease : "");
+}
+
 /*
  *  call-seq:
  *     Rugged.features -> [feature, ...]
@@ -585,6 +600,7 @@ void Init_rugged(void)
 	}
 
 	rb_define_module_function(rb_mRugged, "libgit2_version", rb_git_libgit2_version, 0);
+	rb_define_module_function(rb_mRugged, "libgit2_prerelease", rb_git_libgit2_prerelease, 0);
 	rb_define_module_function(rb_mRugged, "features", rb_git_features, 0);
 	rb_define_module_function(rb_mRugged, "valid_full_oid?", rb_git_valid_full_oid, 1);
 	rb_define_module_function(rb_mRugged, "hex_to_raw", rb_git_hex_to_raw, 1);
